==> rucio-0.1.14.tar.gz: rucio-0.1.14/tools/exec_cmd.sh <==
#!/usr/bin/env sh

cmd="/bin/rm -rf /tmp/pip-build-root/"
cmd="/etc/init.d/httpd restart"
#cmd="/usr/bin/puppet  agent --test --verbose --debug --no-daemonize"
#cmd="/usr/bin/pip-python install --verbose --upgrade rucio"
cmd="/bin/rm -rf /tmp/pip-build-root/; /usr/bin/pip-python install --verbose --upgrade rucio; /etc/init.d/httpd restart"
#cmd="/bin/rm -rf /tmp/pip-build-root/; /usr/bin/pip-python install --verbose --upgrade rucio"
#cmd="/usr/bin/pip-python install  distribute==0.6.48"
cmd="/etc/init.d/httpd restart"
#cmd="/usr/bin/pip-python freeze|grep rucio" 
cmd="/usr/bin/supervisorctl restart all"
#cmd="/etc/init.d/httpd stop"
#cmd="/usr/bin/supervisorctl stop all"
#cmd="/usr/bin/pip-python freeze|grep SQLAlchemy" 
echo "$cmd"
ssh root@voatlasrucio-auth-dev-01     "$cmd"
ssh root@voatlasrucio-auth-prod-01    "$cmd" 
ssh root@voatlasrucio-auth-prod-02    "$cmd" 
ssh root@voatlasrucio-daemon-dev-01   "$cmd" 
ssh root@voatlasrucio-daemon-dev-02   "$cmd" 
#ssh root@voatlasrucio-daemon-prod-01  "$cmd" 
#ssh root@voatlasrucio-daemon-prod-02  "$cmd" 
#ssh root@voatlasrucio-daemon-prod-03  "$cmd" 
#ssh root@voatlasrucio-daemon-prod-04  "$cmd" 
#ssh root@voatlasrucio-daemon-prod-05  "$cmd" 
#ssh root@voatlasrucio-server-dev-01   "$cmd" 
#ssh root@voatlasrucio-server-dev-02   "$cmd" 
#ssh root@voatlasrucio-server-dev-03   "$cmd"
#ssh root@voatlasrucio-server-dev-04   "$cmd"
#ssh root@voatlasrucio-server-prod-01  "$cmd" 
#ssh root@voatlasrucio-server-prod-02  "$cmd" 
#ssh root@voatlasrucio-server-prod-03  "$cmd"

==> rucio-0.1.15.tar.gz: rucio-0.1.15/tools/exec_cmd.sh <==
#!/usr/bin/env sh

cmd="/bin/rm -rf /tmp/pip-build-root/"
cmd="/etc/init.d/httpd restart"
#cmd="/usr/bin/puppet  agent --test --verbose --debug --no-daemonize"
#cmd="/usr/bin/pip-python install --verbose --upgrade rucio"
cmd="/bin/rm -rf /tmp/pip-build-root/; /usr/bin/pip-python install --verbose --upgrade rucio; /etc/init.d/httpd restart"
#cmd="/bin/rm -rf /tmp/pip-build-root/; /usr/bin/pip-python install --verbose --upgrade rucio"
#cmd="/usr/bin/pip-python install  distribute==0.6.48"
#cmd="/etc/init.d/httpd restart"
#cmd="/usr/bin/pip-python freeze|grep rucio" 
cmd="/usr/bin/pip-python freeze|grep SQLAlchemy"
#cmd="/usr/bin/supervisorctl restart all"
#cmd="/etc/init.d/httpd stop"
#cmd="/usr/bin/supervisorctl stop all"
#cmd="/usr/bin/pip-python freeze|grep SQLAlchemy" 
echo "$cmd"

ssh root@voatlasrucio-auth-dev-01     "$cmd"
ssh root@voatlasrucio-daemon-dev-01   "$cmd" 
ssh root@voatlasrucio-daemon-dev-02   "$cmd" 
ssh root@voatlasrucio-server-dev-01   "$cmd" 
ssh root@voatlasrucio-server-dev-02   "$cmd" 
ssh root@voatlasrucio-server-dev-03   "$cmd"
ssh root@voatlasrucio-server-dev-04   "$cmd"

#ssh root@voatlasrucio-auth-prod-01    "$cmd"
#ssh root@voatlasrucio-auth-prod-02    "$cmd"
#ssh root@voatlasrucio-daemon-prod-01  "$cmd"
#ssh root@voatlasrucio-daemon-prod-02  "$cmd"
#ssh root@voatlasrucio-daemon-prod-03  "$cmd"
#ssh root@voatlasrucio-daemon-prod-04  "$cmd"
#ssh root@voatlasrucio-daemon-prod-05  "$cmd"
#ssh root@voatlasrucio-server-prod-01  "$cmd" 
#ssh root@voatlasrucio-server-prod-02  "$cmd" 
#ssh root@voatlasrucio-server-prod-03  "$cmd"
